'use strict';

const gulp = require('gulp');
const clean = require('gulp-clean');
const sass = require('gulp-sass');
const bulkSass = require('gulp-sass-bulk-import');
const cssBase64 = require('gulp-css-base64');
const themesCombiner = require('gulp-sass-themes-combiner');
const hash = require('gulp-hash');
const sassVariables = require('gulp-sass-variables');
const autoprefixer = require('gulp-autoprefixer');

const DIST_PATH = './dist';
const SRC_PATH = './app';

gulp.task('clean', () => {
    gulp.src(`${DIST_PATH}/*.css`, {read: false})
        .pipe(clean());
});

gulp.task('styles', ['static'], () => {
    let themes = themesCombiner(`${SRC_PATH}/styles/themes/_*.scss`);

    return gulp.src(`${SRC_PATH}/styles/app.themed.scss`)
        .pipe(themes.init())
        .pipe(bulkSass())
        .pipe(sassVariables({
            $cdn: process.env.NODE_CDN_PATH
        }))
        .pipe(sass({
            outputStyle: 'compressed',
            includePaths: [
                require('node-normalize-scss').includePaths
            ]
        })).on('error', sass.logError)
        .pipe(autoprefixer())
        .pipe(themes.combine('app'))
        .pipe(cssBase64({
            baseDir: './app',
            maxWeightResource: 100000,
            extensionsAllowed: ['.svg', '.jpg', '.jpeg', '.png', '.woff', '.woff2']
        }))
        .pipe(gulp.dest(`${DIST_PATH}`));
});

gulp.task('styles-assets', ['styles'], () => {
    gulp.src(`${DIST_PATH}/*.css`)
        .pipe(clean({force: true}))
        .pipe(hash())
        .pipe(gulp.dest(DIST_PATH))
        .pipe(hash.manifest('./themes-assets.json'))
        .pipe(gulp.dest('./'));
});

gulp.task('static', () => {
    gulp.src(`${SRC_PATH}/images/static/**/*.*`)
        .pipe(gulp.dest(`${DIST_PATH}/static`));
});

gulp.task('build', ['styles-assets']);

gulp.task('watch', ['styles'], () => {
    gulp.watch([`${SRC_PATH}/styles/**/*.scss`, `${SRC_PATH}/images/**/*.*`], ['styles']);
});
